@@ -97,11 +97,12 @@ static NSString *const VLCNetworkLoginDataSourceProtocolCellIdentifier = @"VLCNe
 
             // Always use black since the background is always white.
             [self.segmentedControl setTitleTextAttributes:@{NSForegroundColorAttributeName:
-                                                                [UIColor blackColor]}
+                                                                UIColor.blackColor}
                                                  forState:UIControlStateSelected];
         }
         [self.contentView addSubview:_segmentedControl];
-        self.backgroundColor = PresentationTheme.current.colors.background;
+        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(themeDidChange) name:kVLCThemeDidChangeNotification object:nil];
+        [self themeDidChange];
     }
     return self;
 }
@@ -112,4 +113,9 @@ static NSString *const VLCNetworkLoginDataSourceProtocolCellIdentifier = @"VLCNe
     self.segmentedControl.frame = CGRectInset(self.contentView.bounds, 20, 5);
 }
 
+- (void)themeDidChange
+{
+    self.backgroundColor = PresentationTheme.current.colors.background;
+}
+
 @end
